@@ -6,32 +6,9 @@ import numpy as np
 import scipy.stats as st
 from mxnet.lr_scheduler import LRScheduler, FactorScheduler, PolyScheduler, MultiFactorScheduler, CosineScheduler
 
-__all__ = ["get_lr_scheduler", "plot_schedule"]
+from longling.ML.DL import get_total_update_steps, get_factor_lr_params, stop_lr as _stop_lr
 
-
-def get_total_update_steps(update_epoch, batches_per_epoch, epoch_update_freq=1):
-    return int(update_epoch * batches_per_epoch * epoch_update_freq)
-
-
-def _stop_lr(base_lr, stop_lr=None, discount=None):
-    assert stop_lr or discount
-    if stop_lr:
-        return stop_lr, discount
-    elif discount:
-        return base_lr * discount, discount
-
-
-def get_factor_lr_params(base_lr, update_epoch, batches_per_epoch, epoch_update_freq=1, stop_lr=None, discount=None):
-    assert epoch_update_freq
-
-    total_update_steps = get_total_update_steps(
-        update_epoch,
-        batches_per_epoch,
-        epoch_update_freq
-    )
-    step = batches_per_epoch // epoch_update_freq
-    stop_lr, discount = _stop_lr(base_lr, stop_lr, discount)
-    return step, pow(discount, step / total_update_steps), stop_lr
+__all__ = ["get_lr_scheduler", "plot_schedule", "get_total_update_steps"]
 
 
 class _LRScheduler(LRScheduler):
@@ -327,13 +304,18 @@ SCHEDULERS = {
 }
 
 
-def get_lr_scheduler(scheduler: (str, LRScheduler) = "cosine", logger=logging, update_params=None, **kwargs):
-    for key in {"learning_rate", "lr"}:
-        if key in kwargs:
-            kwargs["base_lr"] = kwargs.pop(key)
+def get_lr_scheduler(scheduler: (str, LRScheduler) = "cosine", logger=logging, update_params=None, adaptive=True,
+                     **kwargs):
+    if adaptive is True:
+        for key in {"learning_rate", "lr"}:
+            if key in kwargs:
+                kwargs["base_lr"] = kwargs.pop(key)
 
-    if isinstance(scheduler, str):
-        scheduler = SCHEDULERS[scheduler].init(**kwargs)
+        if isinstance(scheduler, str):
+            scheduler = SCHEDULERS[scheduler].init(**kwargs)
+    else:
+        if isinstance(scheduler, str):
+            scheduler = eval(scheduler)(**kwargs)
 
     assert isinstance(scheduler, LRScheduler)
 
